jpeg-related keywords and rcParams
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

Support has been removed for the *quality*, *optimize*, and *progressive*
parameters of `.Figure.savefig` (which only affected jpeg output), as well as
:rc:`savefig.jpeg_quality`.  This support has also been removed from the
corresponding ``print_jpg`` methods.

JPEG output options can be set by directly passing the relevant parameters in
*pil_kwargs*.
